Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Request ¶
type Request struct {
Method string
Params map[string]string
Headers map[string]string
Data interface{}
}
Request contains the Method used in sending, the Url to request, and
any Data to be sent
type Responder ¶
Responder marshals an http.Response into a service.Response that will
return either a Body() or Error()
type Response ¶
Response contains relevant data from http server responses It can be used in conjunction with the following methods like this:
data, _ := ServiceGet(url) var c []*models.Content err := json.Unmarshal(data, &c)
Since ServiceGet returns data as a []byte, we can unmarshal it to whatever is needed in the calling method. Here, its []*models.Content
Click to show internal directories.
Click to hide internal directories.